Learn R Programming

tcxr (version 0.1.0)

TCXRead: Read and Parse a TCX File

Description

Parses a TCX file to extract key activity metrics such as speed, distance, time, altitude, power, cadence, heart rate, and activity type.

Usage

TCXRead(file_path)

Value

A list containing the computed activity metrics, including the activity type.

Arguments

file_path

A character string specifying the path to the TCX file.