powered by
Parses a TCX file to extract key activity metrics such as speed, distance, time, altitude, power, cadence, heart rate, and activity type.
TCXRead(file_path)
A list containing the computed activity metrics, including the activity type.
A character string specifying the path to the TCX file.